/**
 * The main part of the calculator doing the calculations.
 * 
 * @author  David J. Barnes and Michael Kolling 
 * @version 1.1 - by Viera K. Proulx
 */
public class CalcEngine
{
  // Calculator is represented by two numeric values and the operator
  // as well as the current dispaly value
  
  	int display; //current display on calculator
	int num1;    //current number that's been hit
	Operator op;   //operator
	int num2;    //next number that's been hit	 
			
    /**
     * Create a CalcEngine instance.
     */
	CalcEngine(int display, int num1, Operator op, int num2)
		{
		this.display = display;
		this.num1 = num1;
		this.op = op;
		this.num2 = num2;
 		}

    /**
     * Return the value that should currently be displayed
     * on the calculator display.
     */
    public int getDisplayValue()
    {
        return display;
    }

    /**
     * A number button was pressed.
     * Either start a new operand, or incorporate this number as
     * the least significant digit of an existing one.
     */
    public void numberPressed(int number){
		this.display = (this.num2 * 10) + number;
		this.num2 = (this.num2 * 10) + number;
		// return this;
	}

	// process the operator key press
	CalcEngine operation(Operator op){
		this.display = this.op.evaluate(this.num1, this.num2);
		this.num1 = this.op.evaluate(this.num1, this.num2);
		this.op = op;
		this.num2 = 0;
		return this;
			
		// return new Calculator(op.evaluate(this.num1, this.num2) , op.evaluate(this.num1, this.num2), op, 0);
	} 
	
	// process the equals key press
	CalcEngine equalsOp(){
		this.display = op.evaluate(this.num1, this.num2);
		this.num1 = op.evaluate(this.num1, this.num2);
		this.op = op;
		this.num2 = 0;
		return this;
	} 
	
	// process the clear key press
	CalcEngine clearOp(){
		this.display = 0;
		this.num1 = 0;
		this.op = new Plus();
		this.num2 = 0;
		return this;
	} 
		
    /**
     * The 'plus' button was pressed. 
     */
    public void plus()
    {
	    this.operation(new Plus());
    }

    /**
     * The 'minus' button was pressed.
     */
    public void minus()
    {
	    this.operation(new Subtract());
    }
    
    /**
     * The '=' button was pressed.
     */
    public void equals()
    {
	    this.equalsOp();
    }

    /**
     * The 'C' (clear) button was pressed.
     * Reset everything to a starting state.
     */
    public void clear()
    {
	    this.clearOp();
    }

    /**
     * Return the title of this calculation engine.
     */
    public String getTitle()
    {
        return "Java Calculator";
    }

    /**
     * Return the author of this engine.
     */
    public String getAuthor()
    {
        return "Viera K. Proulx and Tanya Cashorali";
    }

    /**
     * Return the version number of this engine.
     */
    public String getVersion()
    {
       return "Version 1.1";
    }

}
